#
# spec file for package php5-pear-HTTP_Request2
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           php5-pear-HTTP_Request2
%define pear_name  HTTP_Request2
%define pear_sname HTTP_Request2
Summary:        Provides an easy way to perform HTTP requests
License:        BSD-3-Clause
Group:          Development/Libraries/PHP
Version:        2.2.1
Release:        7.3
BuildArch:      noarch
Url:            http://pear.php.net/package/%{pear_name}
Source:         %{pear_name}-%{version}.tgz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  php >= 5.2
%if 0%{?sles_version} == 10
BuildRequires:  php-macros
%else
BuildRequires:  php-devel >= 5.2
%endif
BuildRequires:  php-pear >= 1.9.2
Requires:       php >= 5.2
Requires:       php-pear >= 1.9.2
Requires:       php-pear-Net_URL2 >= 2.0.0

Provides:       pear-%{pear_name}
Provides:       pear-%{pear_sname} = %{version}
Provides:       php-pear-%{pear_name}
Provides:       php-pear-%{pear_sname} = %{version}
Provides:       php5-pear-%{pear_sname} = %{version}
Obsoletes:      pear-%{pear_sname} < %{version}
Obsoletes:      php-pear-%{pear_sname} < %{version}
Obsoletes:      php5-pear-%{pear_sname} < %{version}

%description
PHP5 rewrite of HTTP_Request package (with parts of HTTP_Client). Provides
cleaner API and pluggable Adapters:
* Socket adapter, based on old HTTP_Request code,
* Curl adapter, wraps around PHP's cURL extension,
* Mock adapter, to use for testing packages dependent on HTTP_Request2.
Supports POST requests with data and file uploads, basic and digest
authentication, cookies, managing cookies across requests, proxies, gzip and
deflate encodings, redirects, monitoring the request progress with Observers...


%prep
%setup -c

# Patch package.xml to lower the required PEAR version  to enable build
%if 0%{?suse_version} < 1200 && 0%{?sles_version} != 11
sed -i 's/1.9.2/1.9.1/g' package.xml
%endif

%build

%install
%{__mv} package*.xml %{pear_name}-%{version}
cd %{pear_name}-%{version}
PHP_PEAR_PHP_BIN="$(which php) -d memory_limit=50m"
%{__pear} -v \
        -d bin_dir=%{_bindir} \
        -d data_dir=%{php_peardir}/data \
        -d test_dir=%{php_peardir}/tests \
        install --offline --nodeps -P "%{buildroot}" package.xml

%{__install} -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{__rm} -rf %{buildroot}/{doc,tmp}
%{__rm} -rf %{buildroot}%{php_peardir}/.{filemap,lock,registry,channels,depdb,depdblock}

cd ..

%php_pear_gen_filelist

%post
if [ "$1" = "1" ]; then
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml
fi
if [ "$1" = "2" ]; then
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml
fi

%postun
if [ "$1" = "0" ]; then
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name}
fi

%files -f %{name}.files
%defattr(-, root, root)
%doc %{pear_name}-%{version}/docs/LICENSE
%doc %{pear_name}-%{version}/docs/examples/

%changelog
* Wed May 14 2014 aj@ajaissle.de
- Put a copy of docs/LICENSE and docs/examples/ into %%_docdir
* Tue May 13 2014 aj@ajaissle.de
- New upstream release 2.2.1
- Changelog 2.2.1
  * Fixed a bogus timeout Exception in Socket adapter after waiting for
    "100 Continue" response: the same one-second timeout was used
    for further socket operations if explicit 'timeout' parameter was not set.
    Thanks to Andrea Brancatelli (abrancatelli at schema31 dot it) for the report.
  * Bundled a separate LICENSE file (request #20175). Updated phrasing and links
    to mention 3-Clause BSD license the package actually uses.
- Changelog 2.2.0
  New features
  * Socket adapter will send "Expect: 100-continue" header and wait for
    "100 Continue" response by default before sending large request body
    (request #19233). This can be disabled by setting an empty "Expect"
    header, the same way as done with Curl adapter (see bug #15937)
  * It is possible to specify a local IP address to bind to using 'local_ip'
    configuration parameter (request #19515)
  Other changes and fixes
  * An infinite loop was possible when using a stream wrapper instead of
    a regular file with MultipartBody (bug #19934)
  * Socket adapter will properly send chunked request body if
    "Transfer-Encoding: chunked" header is set for the request (bug #20125)
  * Updated Public Suffix List to the latest version and updated its download script
  * Unit tests fixes
* Mon Jun 17 2013 aj@ajaissle.de
- Fix CookieJar.php checksum in package.xml (bnc#825249)
* Fri Feb  1 2013 aj@ajaissle.de
- New upstream version 2.1.1
- Changelog 2.1.1
  * Fixes for SOCKS5 proxies support in Socket adapter
- Changelog 2.1.0
  * New features:
  * Mock adapter can return responses based on request URL
    (request #19276)
  * Support for SOCKS5 proxies, added 'proxy_type' configuration
    parameter (request #19332)
  * Proxy configuration may be given as an URL, e.g.
    $request->setConfig('proxy', 'socks5://localhost:1080');
  * Other changes and fixes:
  * Coding standards fixes (request #14990)
  * Unit tests now run from SVN checkout and under PHPUnit 3.6.x
  * Explicit dependency on PEAR (until PEAR_Exception is a
    separate package)
  * Get rid of track_errors, use a more robust solution (bug
    [#19337])
  * Additional class_exists() check in setAdapter() (request
    [#19344])
  * Public suffix list updated to current version
- Changelog 2.0.0
  * Added an accessor method for HTTP_Request2_Response::$phrases
    (request #18716)
  * HTTP_Request2::send() throws an exception if URL is not
    provided rather than dies with a fatal error (bug #18755)
  * Public Suffix List updated to current version
- Moved http_request2.patch into the spec file (sed)
* Sat Sep 10 2011 gerrit.beine@gmx.de
- initial version 1.7.12
